Werkzeug
========

Werkzeug started as simple collection of various utilities for WSGI
applications and has become one of the most advanced WSGI utility
modules.  It includes a powerful debugger, full-featured request and
response objects, HTTP utilities to handle entity tags, cache control
headers, HTTP dates, cookie handling, file uploads, a powerful URL
routing system and a bunch of community-contributed addon modules.

Werkzeug is unicode aware and doesn't enforce a specific template
engine, database adapter or anything else.  It doesn't even enforce
a specific way of handling requests and leaves all that up to the
developer. It's most useful for end user applications which should work
on as many server environments as possible (such as blogs, wikis,
bulletin boards, etc.).

Details and example applications are available on the
`Werkzeug website <http://werkzeug.pocoo.org/>`_.


Branches
--------

+----------------------+---------------------------------------------------------------------------------+
| ``master``           | .. image:: https://travis-ci.org/mitsuhiko/werkzeug.svg?branch=master           |
|                      |     :target: https://travis-ci.org/mitsuhiko/werkzeug                           |
+----------------------+---------------------------------------------------------------------------------+
| ``0.9-maintenance``  | .. image:: https://travis-ci.org/mitsuhiko/werkzeug.svg?branch=0.9-maintenance  |
|                      |     :target: https://travis-ci.org/mitsuhiko/werkzeug                           |
+----------------------+---------------------------------------------------------------------------------+
| ``0.10-maintenance`` | .. image:: https://travis-ci.org/mitsuhiko/werkzeug.svg?branch=0.10-maintenance |
|                      |     :target: https://travis-ci.org/mitsuhiko/werkzeug                           |
+----------------------+---------------------------------------------------------------------------------+
